import { QueryTableSource } from '@yukawa/chain-base-angular-store';
import { BehaviorSubject } from 'rxjs';
import { EventEmitter, isDevMode, Component, ViewEncapsulation, Input, Output, ViewChild, NgModule, CUSTOM_ELEMENTS_SCHEMA } from '@angular/core';
import '@angular/cdk/table';
import { MatSort, MatSortModule } from '@angular/material/sort';
import { MatTableModule } from '@angular/material/table';
import { MatSlideToggleModule } from '@angular/material/slide-toggle';
import { MatIconModule } from '@angular/material/icon';
import { MatButtonModule } from '@angular/material/button';
import { MatRippleModule } from '@angular/material/core';
import { FlexLayoutModule } from '@angular/flex-layout';
import { CommonModule } from '@angular/common';
import { MatTooltipModule } from '@angular/material/tooltip';

/**
 * @fileoverview added by tsickle
 * Generated from: file/file-table/file-info-query.store.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FileInfoQueryStore extends QueryTableSource {
    /**
     * @param {?} service
     * @param {?=} paginator
     * @param {?=} sort
     * @param {?=} tableFilter
     */
    constructor(service, paginator, sort, tableFilter) {
        super(paginator, sort, tableFilter);
        this.service = service;
        this.paginator = paginator;
        this.sort = sort;
        this.tableFilter = tableFilter;
        this.filterSubject = new BehaviorSubject(tableFilter);
    }
    /**
     * @protected
     * @return {?}
     */
    queryTable() {
        /** @type {?} */
        let filter = this.findFilter();
        this.applyFilter(filter);
        if (filter.keyword)
            filter.keyword += '*';
        return this.service.queryFiles(filter);
    }
}
if (false) {
    /**
     * @type {?}
     * @protected
     */
    FileInfoQueryStore.prototype.service;
    /**
     * @type {?}
     * @protected
     */
    FileInfoQueryStore.prototype.paginator;
    /**
     * @type {?}
     * @protected
     */
    FileInfoQueryStore.prototype.sort;
    /**
     * @type {?}
     * @protected
     */
    FileInfoQueryStore.prototype.tableFilter;
}

/**
 * @fileoverview added by tsickle
 * Generated from: file/file-table/file-table.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
//import {TableFilter} from "../../../../../../../../../libs/chain-base/front/angular/domain/target/angular";
/** @type {?} */
const TAG = 'FileTableComponent';
class FileTableComponent {
    constructor() {
        this.displayedColumns = ['icon', 'fileName', 'type', 'size', 'owner', 'created', 'modified', 'detail-button'];
        //@Output()
        //rowSelected = new EventEmitter<FileInfo|any>();
        this.action = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     * On destroy
     * @return {?}
     */
    ngOnDestroy() {
        // Unsubscribe from all subscriptions
        // this.rowSelected.next();
        this.action.complete();
    }
    /**
     * @param {?} event
     * @param {?} cmd
     * @param {?} selected
     * @return {?}
     */
    onAction(event, cmd, selected) {
        if (isDevMode()) {
            console.debug(TAG, "onAction", cmd, selected);
        }
        event.stopPropagation();
        this.fireAction((/** @type {?} */ ({ name: cmd, payload: selected })));
    }
    /**
     * @protected
     * @param {?} action
     * @return {?}
     */
    fireAction(action) {
        this.action.emit(action);
    }
}
FileTableComponent.decorators = [
    { type: Component, args: [{
                selector: 'chain-docs-file-table',
                template: "<mat-table #table [dataSource]=\"dataSource\" matSort>    <!--[@animateStagger]=\"{value:'50'}\"-->\n\n    <!-- Type Column -->\n    <ng-container matColumnDef=\"icon\">\n        <mat-header-cell *matHeaderCellDef fxFlex=\"64px\"></mat-header-cell>\n        <mat-cell *matCellDef=\"let row\" fxFlex=\"64px\">\n            <mat-icon class=\"type-icon\" [ngClass]=\"row.type\"></mat-icon>\n        </mat-cell>\n    </ng-container>\n\n    <!-- Name Column -->\n    <ng-container matColumnDef=\"fileName\">\n        <mat-header-cell mat-sort-header *matHeaderCellDef>Name</mat-header-cell>\n        <mat-cell *matCellDef=\"let row\"> {{row.fileName}}</mat-cell>\n    </ng-container>\n\n    <!-- Type Column -->\n    <ng-container matColumnDef=\"type\">\n        <mat-header-cell mat-sort-header *matHeaderCellDef fxHide fxShow.gt-md>Type</mat-header-cell>\n        <mat-cell *matCellDef=\"let row\" fxHide fxShow.gt-md> {{row.type}}</mat-cell>\n    </ng-container>\n\n    <!-- Owner Column -->\n    <ng-container matColumnDef=\"owner\">\n        <mat-header-cell mat-sort-header *matHeaderCellDef fxHide.xs>Owner</mat-header-cell>\n        <mat-cell *matCellDef=\"let row\" fxHide.xs> {{row.created?.user}}</mat-cell>\n    </ng-container>\n\n    <!-- Size Column -->\n    <ng-container matColumnDef=\"size\">\n        <mat-header-cell mat-sort-header *matHeaderCellDef fxHide.xs>Size</mat-header-cell>\n        <mat-cell *matCellDef=\"let row\" fxHide.xs>-</mat-cell>\n    </ng-container>\n    <!-- Created Column mat-sort-header -->\n    <ng-container matColumnDef=\"created\">\n        <mat-header-cell *matHeaderCellDef fxHide fxShow.gt-md>Created</mat-header-cell>\n        <mat-cell *matCellDef=\"let row\" fxHide fxShow.gt-md>{{row.created?.date | date}}</mat-cell>\n    </ng-container>\n\n    <!-- Modified Column mat-sort-header -->\n    <ng-container matColumnDef=\"modified\">\n        <mat-header-cell *matHeaderCellDef fxHide fxShow.gt-md>Modified</mat-header-cell>\n        <mat-cell *matCellDef=\"let row\" fxHide fxShow.gt-md>{{row.change?.date | date}}</mat-cell>\n    </ng-container>\n\n    <!-- Detail Button Column -->\n    <ng-container matColumnDef=\"detail-button\">\n        <mat-header-cell *matHeaderCellDef fxFlex=\"48px\" fxHide.gt-md></mat-header-cell>\n        <mat-cell *matCellDef=\"let row\" fxFlex=\"48px\" fxHide.gt-md>\n            <button mat-icon-button class=\"sidebar-toggle\" fxHide.gt-md\n                    (click)=\"onAction( $event, 'info', row);\">\n                <mat-icon class=\"secondary-text\">info</mat-icon>\n            </button>\n        </mat-cell>\n    </ng-container>\n\n    <mat-header-row *matHeaderRowDef=\"displayedColumns\"></mat-header-row>\n    <mat-row *matRowDef=\"let row; columns: displayedColumns;\"\n             (click)=\"onAction($event,'select', row)\"\n             [ngClass]=\"{'selected' : row == selected}\" matRipple>\n        <!--[@animate]=\"{value:'*',params:{y:'100%'}}\"-->\n    </mat-row>\n    \n</mat-table>",
                encapsulation: ViewEncapsulation.None,
                styles: ["file-list{width:100%}file-list .mat-table{background:0 0;box-shadow:none}file-list .mat-table .mat-row{position:relative;cursor:pointer;min-height:64px}"]
            }] }
];
/** @nocollapse */
FileTableComponent.ctorParameters = () => [];
FileTableComponent.propDecorators = {
    displayedColumns: [{ type: Input }],
    dataSource: [{ type: Input }],
    selected: [{ type: Input }],
    action: [{ type: Output }],
    sort: [{ type: ViewChild, args: [MatSort, { static: true },] }]
};
if (false) {
    /** @type {?} */
    FileTableComponent.prototype.displayedColumns;
    /** @type {?} */
    FileTableComponent.prototype.dataSource;
    /** @type {?} */
    FileTableComponent.prototype.selected;
    /** @type {?} */
    FileTableComponent.prototype.action;
    /** @type {?} */
    FileTableComponent.prototype.sort;
}

/**
 * @fileoverview added by tsickle
 * Generated from: file/file-info/file-info.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const TAG$1 = 'FileInfoComponent';
class FileInfoComponent {
    constructor() {
        this.action = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    // @toDo NR [ww] implement actions in FileManagerComponent.onDetailAction
    /*
         remove(): void {
    
           /*  this.confirmDialogRef = this._matDialog.open(FuseConfirmDialogComponent, {
                 disableClose: false
             });
    
             this.confirmDialogRef.componentInstance.confirmMessage = `Are you sure you want to delete ${this.selected.fileName} ?`;
    
             this.confirmDialogRef.afterClosed().subscribe(result => {
                 if (result) {
                     this._fileManagerService.deleteDirectory(this.selected.fileId).subscribe(res => {
                         this._fileManagerService.getFiles({ parentId: this._fileManagerService.currentfileId });
                     });
                 }
             });
         }
    
         goto(): void {
             //
             // this._fileManagerService.downloadFile(this.selected.fileId, this.selected.mime).subscribe(res => {
             //     FileSaver.saveAs(res, this.selected.fileName);
             // }), error => console.log('Error downloading the file'),
             //     () => console.info('File downloaded successfully')
         }  */
    /**
     * @param {?} cmd
     * @param {?=} selected
     * @return {?}
     */
    onAction(cmd, selected = this.value) {
        if (isDevMode()) {
            console.debug(TAG$1, "onAction", cmd, selected);
        }
        this.fireAction((/** @type {?} */ ({ name: cmd, payload: selected })));
    }
    /**
     * @protected
     * @param {?} action
     * @return {?}
     */
    fireAction(action) {
        this.action.emit(action);
    }
}
FileInfoComponent.decorators = [
    { type: Component, args: [{
                selector: 'chain-docs-file-info',
                template: "<!-- SIDEBAR HEADER -->\n<div class=\"header accent p-24\" fxLayout=\"column\" fxLayoutAlign=\"space-between\">\n\n    <div class=\"toolbar\" fxLayout=\"row\" fxLayoutAlign=\"end center\">\n\n        <button (click)=\"onAction('delete')\"  mat-icon-button matTooltip=\"Delete\">\n            <mat-icon>delete</mat-icon>\n        </button>\n\n        <button *ngIf=\"value?.type!='DIRECTORY'\" (click)=\"onAction('download')\" mat-icon-button  aria-label=\"Download\" matTooltip=\"Download\">\n            <mat-icon>cloud_download</mat-icon>\n        </button>\n\n        <!--<input (change)=\"onAction('upload')\" hidden type=\"file\" #fileInput/>-->\n        <button *ngIf=\"value?.type!='DIRECTORY'\" (click)=\"onAction('upload')\" mat-icon-button  aria-label=\"Download\" matTooltip=\"Upload\">\n            <mat-icon>cloud_upload</mat-icon>\n        </button>\n\n        <button mat-icon-button aria-label=\"More\" matTooltip=\"More\">\n            <mat-icon>more_vert</mat-icon>\n        </button>\n    </div>\n\n    <div>\n        <div class=\"title mb-8\">{{value?.fileName}}</div>\n        <div class=\"subtitle secondary-text\">\n            <span>Edited</span>\n            <span *ngIf=\"value\">: {{value?.change?.date | date}}</span>\n        </div>\n    </div>\n</div>\n<!-- / SIDEBAR HEADER -->\n\n<!-- SIDEBAR CONTENT -->\n<div class=\"content p-24\" fusePerfectScrollbar>\n   <!-- [@animate]=\"{value:'*',params:{delay:'200ms'}}\"-->\n    <div class=\"file-details\" >\n\n        <div class=\"preview file-icon\" fxLayout=\"row\" fxLayoutAlign=\"center center\">\n            <mat-icon class=\"type-icon s-48\" [ngClass]=\"value?.type\"></mat-icon>\n        </div>\n\n        <div *ngIf=\"value\" class=\"offline-switch\">\n            <mat-slide-toggle [(ngModel)]=\"isPrivate\" labelPosition=\"before\">Private</mat-slide-toggle>\n        </div>\n\n        <div class=\"title\">Info</div>\n\n\n        <table>\n            <tr class=\"type\">\n                <th>Type</th>\n                <td>{{value?.type}}</td>\n            </tr>\n\n            <tr class=\"size\">\n                <th>Size</th>\n                <td>-</td>\n            </tr>\n\n            <!-- <tr class=\"location\">\n                <th>Location</th>\n                <td>{{selected.location}}</td>\n            </tr> -->\n\n            <tr class=\"owner\">\n                <th>Owner</th>\n                <td>{{value?.created?.user}}</td>\n            </tr>\n\n            <tr class=\"modified\">\n                <th>Modified</th>\n                <td>{{value?.change?.date | date}}</td>\n            </tr>\n\n            <!-- <tr class=\"opened\">\n                <th>Opened</th>\n                <td>{{selected.opened}}</td>\n            </tr> -->\n\n            <tr class=\"created\">\n                <th>Created</th>\n                <td>{{value?.created?.date | date}}</td>\n            </tr>\n        </table>\n    </div>\n\n</div>\n<!-- / SIDEBAR CONTENT -->",
                styles: [":host{display:flex;flex-direction:column;flex:1 1 auto;height:100%}:host>.header{flex:0 1 auto;height:160px;min-height:160px;max-height:160px}:host>.content{flex:1}:host>.content .file-details .preview{height:240px}:host>.content .file-details .offline-switch{padding-bottom:16px;font-weight:600}:host>.content .file-details .title{padding:16px 0}:host>.content .file-details table{width:100%;text-align:left}:host>.content .file-details table tr td,:host>.content .file-details table tr th{padding:16px 0}:host>.content .file-details table tr.type{text-transform:capitalize}:host>.content .file-details table tr.owner{text-transform:capitalize}"]
            }] }
];
/** @nocollapse */
FileInfoComponent.ctorParameters = () => [];
FileInfoComponent.propDecorators = {
    value: [{ type: Input }],
    isPrivate: [{ type: Input }],
    action: [{ type: Output }]
};
if (false) {
    /** @type {?} */
    FileInfoComponent.prototype.value;
    /** @type {?} */
    FileInfoComponent.prototype.isPrivate;
    /** @type {?} */
    FileInfoComponent.prototype.action;
}

/**
 * @fileoverview added by tsickle
 * Generated from: file-comp.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
//import {MatSortModule} from "@angular/material/sort";
class FileCompModule {
}
FileCompModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    FileTableComponent,
                    FileInfoComponent
                ],
                imports: [
                    // BrowserModule,
                    // BrowserAnimationsModule,
                    CommonModule,
                    //BrowserAnimationsModule,
                    MatButtonModule,
                    MatIconModule,
                    MatRippleModule,
                    MatSlideToggleModule,
                    MatTableModule,
                    MatSortModule,
                    MatTooltipModule,
                    FlexLayoutModule
                ],
                exports: [
                    FileTableComponent,
                    FileInfoComponent
                ],
                schemas: [CUSTOM_ELEMENTS_SCHEMA]
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: public-api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: yukawa-chain-docs-angular-comp.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { FileCompModule, FileInfoComponent, FileInfoQueryStore, FileTableComponent };
//# sourceMappingURL=yukawa-chain-docs-angular-comp.js.map
